==> zendesk_classic-0.0.2.tar.gz: README.md <==
# zendesk_classic

Zendesk Plugin

<p align="left">
<a href="https://opensource.org/licenses/MIT"><img src="https://img.shields.io/badge/license-MIT-purple.svg" alt="License: MIT"></a>
</p>

## Getting Started

### Add dependency to your flutter project

```commandline
 flutter pub add zendesk_classic 
```

| SDK          | Android | IOS |
|:-------------|:-------:|----:|
| Support SDK  |    ✅    |   ❌ |
| Support Chat |    ✅    |   ✅ |
| Support Bot  |    ✅    |   ❌ |

### Zendesk Chat Support

```dart

await
_zendeskClassicPlugin.initZendeskChat
('Your Zendesk Account Key
'
,barTintColor: 0xFFFF0000,
tintColor: 0xFFFFFFFF,
backgroundColor: 0xFF000000,
botName
    :
'
Your Bot Name
'
,
);
```

## Android Theme

Please add the below theme to your ```styles.xml``` file in the android ``` res/values``` folder

```xml

<style name="ZendeskSdkTheme" parent="@style/Theme.AppCompat">
    <item name="android:windowBackground">?android:colorBackground</item>
    <item name="colorAccent">@color/zui_color_red_600</item>
    <item name="colorPrimary">@color/zui_color_red_600</item>
    <item name="colorPrimaryDark">@color/zui_color_red_600</item>
</style>
```
You can find the Chat key in your Zendesk dashboard under ```Dashboard > Simulate Conversation```
On the Url You can find the key as shown below
```https://www.zopim.com/widget/livechat.html?Accountkey= Your Zendesk Account Key```

## Support

<a href="https://www.buymeacoffee.com/avinashgotluru" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/v2/default-yellow.png" alt="Buy Me A Coffee" style="height: 60px !important;width: 217px !important;" ></a>

## Contact us

Please drop a mail to [agkc@googlegroups.com](mailto:agkc@googlegroups.com)

## Screenshots

### Android

![Android.png](images%2FAndroid.png)

### IOS

![ios.png](images%2Fios.png)

==> zendesk_classic-0.0.3.tar.gz: README.md <==
# zendesk_classic

Zendesk Plugin

<p align="left">
<a href="https://opensource.org/licenses/MIT"><img src="https://img.shields.io/badge/license-MIT-purple.svg" alt="License: MIT"></a>
</p>

## Getting Started

### Add dependency to your flutter project

```commandline
 flutter pub add zendesk_classic 
```

| SDK          | Android | IOS |
|:-------------|:-------:|----:|
| Support SDK  |    ✅    |   ❌ |
| Support Chat |    ✅    |   ✅ |
| Support Bot  |    ✅    |   ❌ |

### Zendesk Chat Support

```dart
Future<void> initializeChat() async {
  try {
    await _zendeskClassicPlugin.initZendeskChat('Your Zendesk Account Key',
        barTintColor: 0xFFFF0000,
        tintColor: 0xFFFFFFFF,
        backgroundColor: 0xFF000000,
        botName: 'CompanyName');
  } on PlatformException {
    _platformVersion = "Failed to get platform version";
  }
}
```

## Android Theme

Please add the below theme to your ```styles.xml``` file in the android ``` res/values``` folder

```xml

<style name="ZendeskSdkTheme" parent="@style/Theme.AppCompat">
    <item name="android:windowBackground">?android:colorBackground</item>
    <item name="colorAccent">@color/zui_color_red_600</item>
    <item name="colorPrimary">@color/zui_color_red_600</item>
    <item name="colorPrimaryDark">@color/zui_color_red_600</item>
</style>
```
You can find the Chat key in your Zendesk dashboard under ```Dashboard > Simulate Conversation```
On the Url You can find the key as shown below
```https://www.zopim.com/widget/livechat.html?Accountkey= Your Zendesk Account Key```

## Support

<a href="https://www.buymeacoffee.com/avinashgotluru" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/v2/default-yellow.png" alt="Buy Me A Coffee" style="height: 60px !important;width: 217px !important;" ></a>

## Contact us

Please drop a mail to [agkc@googlegroups.com](mailto:agkc@googlegroups.com)

## Screenshots

### Android

![Android.png](images%2FAndroid.png)

### IOS

![ios.png](images%2Fios.png)
